@@ -1,30 +1,25 @@
 # -*- coding: utf-8 -*-
 # stdlib modules
 import logging
-import re
 import pathlib
+import re
 import tempfile
-
 from datetime import datetime
 from pprint import pprint as pp
 
 # Third party modules
 import pymongo
-
 from cyvcf2 import VCF
 from intervaltree import IntervalTree
+from pymongo.errors import BulkWriteError, DuplicateKeyError
 
+from scout.build import build_variant
+from scout.exceptions import IntegrityError
+from scout.parse.variant import parse_variant
 # Local modules
 from scout.parse.variant.rank_score import parse_rank_score
-
-from scout.parse.variant import parse_variant
-from scout.build import build_variant
-
 from scout.utils.coordinates import is_par
 
-from pymongo.errors import DuplicateKeyError, BulkWriteError
-from scout.exceptions import IntegrityError
-
 from .variant_loader import VariantLoader
 
 LOG = logging.getLogger(__name__)
@@ -34,18 +29,18 @@ class VariantHandler(VariantLoader):
 
     """Methods to handle variants in the mongo adapter"""
 
-    def add_gene_info(self, variant_obj, gene_panels=None):
+    def add_gene_info(self, variant_obj, gene_panels=None, build=None):
         """Add extra information about genes from gene panels
 
         Args:
             variant_obj(dict): A variant from the database
             gene_panels(list(dict)): List of panels from database
+            build(str): chromosome build 37 or 38
         """
         gene_panels = gene_panels or []
 
         # Add a variable that checks if there are any refseq transcripts
         variant_obj["has_refseq"] = False
-
         # We need to check if there are any additional information in the gene panels
 
         # extra_info will hold information from gene panels
@@ -64,7 +59,7 @@ class VariantHandler(VariantLoader):
         for variant_gene in variant_obj.get("genes", []):
             hgnc_id = variant_gene["hgnc_id"]
             # Get the hgnc_gene
-            hgnc_gene = self.hgnc_gene(hgnc_id)
+            hgnc_gene = self.hgnc_gene(hgnc_id, build)
 
             if not hgnc_gene:
                 continue
@@ -263,13 +258,27 @@ class VariantHandler(VariantLoader):
             query["_id"] = document_id
 
         variant_obj = self.variant_collection.find_one(query)
-        if variant_obj:
-            variant_obj = self.add_gene_info(variant_obj, gene_panels)
-            if variant_obj["chromosome"] in ["X", "Y"]:
-                ## TODO add the build here
-                variant_obj["is_par"] = is_par(
-                    variant_obj["chromosome"], variant_obj["position"]
-                )
+        if not variant_obj:
+            return variant_obj
+        case_obj = self.case(case_id=variant_obj["case_id"])
+
+        if case_obj:
+            variant_obj = self.add_gene_info(
+                variant_obj=variant_obj,
+                gene_panels=gene_panels,
+                build=case_obj["genome_build"],
+            )
+        else:
+            variant_obj = self.add_gene_info(
+                variant_obj=variant_obj, gene_panels=gene_panels
+            )
+
+        if variant_obj["chromosome"] in ["X", "Y"]:
+            # TODO add the build here
+            variant_obj["is_par"] = is_par(
+                variant_obj["chromosome"], variant_obj["position"]
+            )
+
         return variant_obj
 
     def gene_variants(
@@ -581,8 +590,13 @@ class VariantHandler(VariantLoader):
 
         # Collect the result in a dictionary
         variants = {}
+        case_obj = self.case(
+            case_id=case_id
+        )  # case exists since it's used in the query above
         for var in self.variant_collection.find(query):
-            variants[var["variant_id"]] = self.add_gene_info(var)
+            variants[var["variant_id"]] = self.add_gene_info(
+                variant_obj=var, build=case_obj["genome_build"]
+            )
 
         # Collect all variant comments from the case
         event_query = {
@@ -650,6 +664,8 @@ class VariantHandler(VariantLoader):
                 variant_file = case_obj["vcf_files"].get("vcf_sv")
             elif category == "str":
                 variant_file = case_obj["vcf_files"].get("vcf_str")
+            elif category == "cancer":
+                variant_file = case_obj["vcf_files"].get("vcf_cancer")
         elif variant_type == "research":
             if category == "snv":
                 variant_file = case_obj["vcf_files"].get("vcf_snv_research")
@@ -657,9 +673,17 @@ class VariantHandler(VariantLoader):
                 variant_file = case_obj["vcf_files"].get("vcf_sv_research")
 
         if not variant_file:
-            raise SyntaxError("Vcf file does not seem to exist")
+            raise FileNotFoundError("VCF file does not seem to exist")
+
+        try:
+            vcf_obj = VCF(variant_file)
+        except Exception:
+            raise FileNotFoundError(
+                "Could not access {}. The file is missing or malformed".format(
+                    variant_file
+                )
+            )
 
-        vcf_obj = VCF(variant_file)
         region = ""
 
         if gene_obj:
@@ -681,8 +705,13 @@ class VariantHandler(VariantLoader):
             for header_line in vcf_obj.raw_header.split("\n"):
                 if len(header_line) > 3:
                     temp.write(header_line + "\n")
-            for variant in vcf_obj(region):
-                temp.write(str(variant))
+            try:
+                for variant in vcf_obj(region):
+                    temp.write(str(variant))
+            except Exception:
+                raise FileNotFoundError(
+                    "Could not find index for {}".format(variant_file)
+                )
 
         return file_name
 
