@@ -1,11 +1,11 @@
-# -*- coding: utf-8 -*-
+"""Code for CLI base"""
 import logging
-import sys
+import pathlib
 
 import click
 import coloredlogs
 import yaml
-from flask.cli import FlaskGroup, current_app, with_appcontext
+from flask.cli import FlaskGroup, with_appcontext
 
 # General, logging
 from scout import __version__
@@ -14,7 +14,6 @@ from scout.commands.delete import delete
 from scout.commands.download import download as download_command
 from scout.commands.export import export
 from scout.commands.index_command import index as index_command
-
 # Commands
 from scout.commands.load import load as load_command
 from scout.commands.serve import serve
@@ -22,7 +21,6 @@ from scout.commands.setup import setup as setup_command
 from scout.commands.update import update as update_command
 from scout.commands.view import view as view_command
 from scout.commands.wipe_database import wipe
-from scout.server import extensions
 from scout.server.app import create_app
 
 LOG_LEVELS = ["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"]
@@ -32,9 +30,9 @@ LOG = logging.getLogger(__name__)
 @click.pass_context
 def loglevel(ctx):
     """Set app cli log level"""
-    loglevel = ctx.find_root().params["loglevel"]
+    log_level = ctx.find_root().params["loglevel"]
     log_format = None
-    coloredlogs.install(level=loglevel, fmt=log_format)
+    coloredlogs.install(level=log_level, fmt=log_format)
     LOG.info("Running scout version %s", __version__)
     LOG.debug("Debug logging enabled.")
 
@@ -51,24 +49,37 @@ def get_app(ctx):
         with open(options.params["config"], "r") as in_handle:
             cli_config = yaml.load(in_handle, Loader=yaml.FullLoader)
 
+    flask_conf = None
+    if options.params.get("flask_config"):
+        flask_conf = pathlib.Path(options.params["flask_config"]).absolute()
+
     if options.params.get("demo"):
         cli_config["demo"] = "scout-demo"
 
-    app = create_app(
-        config=dict(
-            MONGO_DBNAME=cli_config.get("demo")
-            or options.params.get("mongodb")
-            or cli_config.get("mongodb")
-            or "scout",
-            MONGO_HOST=options.params.get("host")
-            or cli_config.get("host")
-            or "localhost",
-            MONGO_PORT=options.params.get("port") or cli_config.get("port") or 27017,
-            MONGO_USERNAME=options.params.get("username") or cli_config.get("username"),
-            MONGO_PASSWORD=options.params.get("password") or cli_config.get("password"),
-            OMIM_API_KEY=cli_config.get("omim_api_key"),
+    try:
+        app = create_app(
+            config=dict(
+                MONGO_DBNAME=cli_config.get("demo")
+                or options.params.get("mongodb")
+                or cli_config.get("mongodb")
+                or "scout",
+                MONGO_HOST=options.params.get("host")
+                or cli_config.get("host")
+                or "localhost",
+                MONGO_PORT=options.params.get("port")
+                or cli_config.get("port")
+                or 27017,
+                MONGO_USERNAME=options.params.get("username")
+                or cli_config.get("username"),
+                MONGO_PASSWORD=options.params.get("password")
+                or cli_config.get("password"),
+                OMIM_API_KEY=cli_config.get("omim_api_key"),
+            ),
+            config_file=flask_conf,
         )
-    )
+    except SyntaxError as err:
+        LOG.error(err)
+        raise click.Abort
     return app
 
 
@@ -100,11 +111,13 @@ def get_app(ctx):
 @click.option("-a", "--authdb", help="database to use for authentication")
 @click.option("-port", "--port", help="Specify on what port to listen for the mongod")
 @click.option("-h", "--host", help="Specify the host for the mongo database.")
+@click.option(
+    "-f", "--flask-config", type=click.Path(exists=True), help="Path to flask config."
+)
 @with_appcontext
 def cli(**_):
     """scout: manage interactions with a scout instance."""
     loglevel()
-    pass
 
 
 cli.add_command(load_command)
