@@ -1,55 +1,35 @@
 # -*- coding: utf-8 -*-
+import datetime
 import logging
 import os.path
 import urllib.parse
-
+from datetime import date
 from pprint import pprint as pp
 
+from flask import Response, flash, request, url_for
+from flask_login import current_user
+from flask_mail import Message
+from werkzeug.datastructures import Headers, MultiDict
 from xlsxwriter import Workbook
 
-from datetime import date
-import datetime
-from flask_login import current_user
-from flask import url_for, flash, request, Response
-from flask_mail import Message
-from werkzeug.datastructures import MultiDict, Headers
-
-from scout.constants import (
-    CLINSIG_MAP,
-    ACMG_MAP,
-    ACMG_OPTIONS,
-    ACMG_COMPLETE_MAP,
-    CALLERS,
-    SPIDEX_HUMAN,
-    VERBS_MAP,
-    MOSAICISM_OPTIONS,
-    SEVERE_SO_TERMS,
-    MANUAL_RANK_OPTIONS,
-    CANCER_TIER_OPTIONS,
-    DISMISS_VARIANT_OPTIONS,
-)
+from scout.constants import (ACMG_COMPLETE_MAP, ACMG_MAP, ACMG_OPTIONS,
+                             CALLERS, CANCER_TIER_OPTIONS, CLINSIG_MAP,
+                             DISMISS_VARIANT_OPTIONS, MANUAL_RANK_OPTIONS,
+                             MOSAICISM_OPTIONS, SEVERE_SO_TERMS, SPIDEX_HUMAN,
+                             VERBS_MAP)
 from scout.constants.acmg import ACMG_CRITERIA
-from scout.constants.variants_export import EXPORT_HEADER, VERIFIED_VARIANTS_HEADER
+from scout.constants.variants_export import (EXPORT_HEADER,
+                                             VERIFIED_VARIANTS_HEADER)
 from scout.export.variant import export_verified_variants
-from scout.server.utils import (
-    institute_and_case,
-    user_institutes,
-    case_append_alignments,
-    variant_case,
-)
-from scout.server.links import add_gene_links, ensembl, add_tx_links
 from scout.server.blueprints.genes.controllers import gene
+from scout.server.blueprints.variant.utils import predictions
+from scout.server.links import add_gene_links, add_tx_links, ensembl
+from scout.server.utils import (case_append_alignments, institute_and_case,
+                                user_institutes, variant_case)
 from scout.utils.scout_requests import fetch_refseq_version
 
-from scout.server.blueprints.variant.utils import predictions
-from .forms import (
-    FiltersForm,
-    SvFiltersForm,
-    StrFiltersForm,
-    CancerFiltersForm,
-    VariantFiltersForm,
-)
-
+from .forms import (CancerFiltersForm, FiltersForm, StrFiltersForm,
+                    SvFiltersForm, VariantFiltersForm)
 
 LOG = logging.getLogger(__name__)
 
@@ -61,7 +41,7 @@ def variants(store, institute_obj, case_obj, variants_query, page=1, per_page=50
     more_variants = True if variant_count > (skip_count + per_page) else False
     variant_res = variants_query.skip(skip_count).limit(per_page)
 
-    genome_build = case_obj.get("genome_build", "37")
+    genome_build = str(case_obj.get("genome_build", "37"))
     if genome_build not in ["37", "38"]:
         genome_build = "37"
 
@@ -100,7 +80,7 @@ def variants(store, institute_obj, case_obj, variants_query, page=1, per_page=50
                 variant_type="clinical",
             )
 
-            if clinical_var_obj != None:
+            if clinical_var_obj is not None:
                 # Get all previous ACMG evalautions of the variant
                 variant_obj["clinical_assessments"] = get_manual_assessments(
                     clinical_var_obj
@@ -125,7 +105,7 @@ def sv_variants(store, institute_obj, case_obj, variants_query, page=1, per_page
     skip_count = per_page * max(page - 1, 0)
     more_variants = True if variants_query.count() > (skip_count + per_page) else False
 
-    genome_build = case_obj.get("genome_build", "37")
+    genome_build = str(case_obj.get("genome_build", "37"))
     if genome_build not in ["37", "38"]:
         genome_build = "37"
 
@@ -142,7 +122,7 @@ def sv_variants(store, institute_obj, case_obj, variants_query, page=1, per_page
                 variant_type="clinical",
             )
 
-            if clinical_var_obj != None:
+            if clinical_var_obj is not None:
                 # Get all previous ACMG evalautions of the variant
                 variant_obj["clinical_assessments"] = get_manual_assessments(
                     clinical_var_obj
@@ -173,7 +153,7 @@ def get_manual_assessments(variant_obj):
 
     for assessment_type in assessment_keywords:
         assessment = {}
-        if variant_obj.get(assessment_type) != None:
+        if variant_obj.get(assessment_type) is not None:
             if assessment_type == "manual_rank":
                 manual_rank = variant_obj[assessment_type]
                 LOG.info("Assessement type {}: {}".format(assessment_type, manual_rank))
@@ -417,6 +397,7 @@ def variant_export_lines(store, case_obj, variants_query):
             variant_line.append(";".join(str(x) for x in gene_names))
             variant_line.append(";".join(str(x) for x in hgvs_c))
         else:
+            i = 0
             while i < 4:
                 variant_line.append("-")  # instead of gene ids
                 i = i + 1
@@ -481,11 +462,8 @@ def get_variant_info(genes):
         if len(c_seq) > 20:
             c_seq = c_seq[:20] + "..."
 
-        if len(genes) == 1:
-            value = ":".join([tx_id, exon, c_seq])
-        else:
-            gene_id = gene_obj.get("hgnc_symbol") or str(gene_obj["hgnc_id"])
-            value = ":".join([gene_id, tx_id, exon, c_seq])
+        gene_id = gene_obj.get("hgnc_symbol") or str(gene_obj["hgnc_id"])
+        value = ":".join([gene_id, tx_id, exon, c_seq])
         data["canonical_transcripts"].append(value)
 
     return data
@@ -592,7 +570,6 @@ def populate_filters_form(
                 "clinsig": [4, 5],
                 "clinsig_confident_always_returned": True,
                 "gnomad_frequency": str(institute_obj["frequency_cutoff"]),
-                "variant_type": "clinical",
                 "gene_panels": clinical_filter_panels,
             }
         )
@@ -698,7 +675,7 @@ def populate_sv_filters_form(store, institute_obj, case_obj, category, request_o
         clinical_symbols = store.clinical_symbols(case_obj) if is_clinical else None
         for hgnc_symbol in form.hgnc_symbols.data:
             if hgnc_symbol.isdigit():
-                hgnc_gene = store.hgnc_gene(int(hgnc_symbol))
+                hgnc_gene = store.hgnc_gene(int(hgnc_symbol), case_obj["genome_build"])
                 if hgnc_gene is None:
                     not_found_ids.append(hgnc_symbol)
                 else:
