@@ -1,30 +1,25 @@
-# -*- coding: utf-8 -*-
-import io
-import os.path
-import shutil
-import logging
+"""Views for the variants"""
 import datetime
-import zipfile
+import io
+import logging
+import os.path
 import pathlib
-import pymongo
+import shutil
+import zipfile
 
-from flask import (
-    Blueprint,
-    request,
-    redirect,
-    abort,
-    flash,
-    current_app,
-    url_for,
-    send_file,
-)
+import pymongo
+from flask import (Blueprint, abort, current_app, flash, redirect, request,
+                   send_file, url_for)
 from flask_login import current_user
 
-from scout.constants import SEVERE_SO_TERMS, MANUAL_RANK_OPTIONS, CANCER_TIER_OPTIONS
+from scout.constants import (CANCER_TIER_OPTIONS, MANUAL_RANK_OPTIONS,
+                             SEVERE_SO_TERMS)
 from scout.server.extensions import store
-from scout.server.utils import templated, institute_and_case
+from scout.server.utils import institute_and_case, templated
+
 from . import controllers
-from .forms import FiltersForm, SvFiltersForm, StrFiltersForm, CancerFiltersForm
+from .forms import (CancerFiltersForm, FiltersForm, StrFiltersForm,
+                    SvFiltersForm)
 
 LOG = logging.getLogger(__name__)
 variants_bp = Blueprint(
@@ -82,7 +77,7 @@ def variants(institute_id, case_name):
         file = request.files[form.symbol_file.name]
 
     if request.files and file and file.filename != "":
-        log.debug("Upload file request files: {0}".format(request.files.to_dict()))
+        LOG.debug("Upload file request files: {0}".format(request.files.to_dict()))
         try:
             stream = io.StringIO(file.stream.read().decode("utf-8"), newline=None)
         except UnicodeDecodeError as error:
@@ -90,7 +85,7 @@ def variants(institute_id, case_name):
             return redirect(request.referrer)
 
         hgnc_symbols_set = set(form.hgnc_symbols.data)
-        log.debug("Symbols prior to upload: {0}".format(hgnc_symbols_set))
+        LOG.debug("Symbols prior to upload: {0}".format(hgnc_symbols_set))
         new_hgnc_symbols = controllers.upload_panel(
             store, institute_id, case_name, stream
         )
@@ -109,7 +104,7 @@ def variants(institute_id, case_name):
         clinical_symbols = store.clinical_symbols(case_obj) if is_clinical else None
         for hgnc_symbol in form.hgnc_symbols.data:
             if hgnc_symbol.isdigit():
-                hgnc_gene = store.hgnc_gene(int(hgnc_symbol))
+                hgnc_gene = store.hgnc_gene(int(hgnc_symbol), case_obj["genome_build"])
                 if hgnc_gene is None:
                     not_found_ids.append(hgnc_symbol)
                 else:
@@ -333,14 +328,14 @@ def cancer_sv_variants(institute_id, case_name):
 @variants_bp.route("/<institute_id>/<case_name>/upload", methods=["POST"])
 def upload_panel(institute_id, case_name):
     """Parse gene panel file and fill in HGNC symbols for filter."""
-    file = form.symbol_file.data
+    panel_file = request.form.symbol_file.data
 
-    if file.filename == "":
+    if panel_file.filename == "":
         flash("No selected file", "warning")
         return redirect(request.referrer)
 
     try:
-        stream = io.StringIO(file.stream.read().decode("utf-8"), newline=None)
+        stream = io.StringIO(panel_file.stream.read().decode("utf-8"), newline=None)
     except UnicodeDecodeError as error:
         flash("Only text files are supported!", "warning")
         return redirect(request.referrer)
@@ -369,13 +364,12 @@ def upload_panel(institute_id, case_name):
             ),
             code=307,
         )
-    else:
-        return redirect(
-            url_for(
-                ".variants", institute_id=institute_id, case_name=case_name, **form.data
-            ),
-            code=307,
-        )
+    return redirect(
+        url_for(
+            ".variants", institute_id=institute_id, case_name=case_name, **form.data
+        ),
+        code=307,
+    )
 
 
 @variants_bp.route("/verified", methods=["GET"])
@@ -395,7 +389,6 @@ def download_verified():
         data = io.BytesIO()
         with zipfile.ZipFile(data, mode="w") as z:
             for f_name in pathlib.Path(temp_excel_dir).iterdir():
-                zipfile.ZipFile
                 z.write(f_name, os.path.basename(f_name))
         data.seek(0)
 
@@ -410,6 +403,5 @@ def download_verified():
             + ".zip",
             cache_timeout=0,
         )
-    else:
-        flash("No verified variants could be exported for user's institutes", "warning")
-        return redirect(request.referrer)
+    flash("No verified variants could be exported for user's institutes", "warning")
+    return redirect(request.referrer)
